@@ -86,12 +86,6 @@ typedef struct {
     int (*alloc_stack)(nvidia_modeset_stack_ptr *sp);
     void (*free_stack)(nvidia_modeset_stack_ptr sp);
 
-    /*
-     * Return list of gpu ids probed by nvidia driver. This function is
-     * deprecated, use enumerate_gpus().
-     */
-    NvBool (*get_gpuid_list)(NvU32 *gpu_ids, NvU32 *gpu_count);
-
     /*
      * Enumerate list of gpus probed by nvidia driver.
      *
