@@ -691,20 +691,20 @@ NvBool NVKMS_API_CALL nvkms_ioctl_from_kapi
  * APIs for locking.
  *************************************************************************/
 
-nvkms_sema_handle_t* nvkms_sema_alloc(void)
+nvkms_sema_handle_t* NVKMS_API_CALL nvkms_sema_alloc(void)
 {
     return NULL;
 }
 
-void nvkms_sema_free(nvkms_sema_handle_t *sema)
+void NVKMS_API_CALL nvkms_sema_free(nvkms_sema_handle_t *sema)
 {
 }
 
-void nvkms_sema_down(nvkms_sema_handle_t *seam)
+void NVKMS_API_CALL nvkms_sema_down(nvkms_sema_handle_t *seam)
 {
 }
 
-void nvkms_sema_up(nvkms_sema_handle_t *sema)
+void NVKMS_API_CALL nvkms_sema_up(nvkms_sema_handle_t *sema)
 {
 }
 
