@@ -59,7 +59,7 @@ typedef NvU32 NvKmsKapiDisplay;
 struct NvKmsKapiDisplayModeTimings {
 
     NvU32 refreshRate;
-    NvU32 pixelClock;
+    NvU32 pixelClockHz;
     NvU32 hVisible;
     NvU32 hSyncStart;
     NvU32 hSyncEnd;
