@@ -98,6 +98,12 @@ NvU32 NV_API_CALL os_get_current_process(void)
     return curproc->p_pid;
 }
 
+NvU32 NV_API_CALL os_get_current_pasid(void)
+{
+    // Unsupported. Return "0" as it's invalid PASID
+    return 0;
+}
+
 NV_STATUS NV_API_CALL os_get_current_thread(NvU64 *threadId)
 {
     if (__NV_ITHREAD())
